@@ -566,6 +566,9 @@ wsp_decode_application_id (struct wsp_header_iter *iter,
         *out_value = get_text_entry (val, app_id);
 
       break;
+    default:
+      g_warning ("Unhandled case");
+      return FALSE;
     }
 
   return TRUE;
